@@ -66,9 +66,18 @@ class event
     /* is this event selected in editing */
     bool m_selected;
 
+    /* is this event marked in processing */
+    bool m_marked;
+
+    /* is this event being painted */
+    bool m_painted;
+    
     /* size of sysex message */
     long m_size;
 
+    /* used in sorting */
+    int get_rank( ) const;
+
  public:
 
     event(); 
@@ -102,6 +111,14 @@ class event
     bool is_linked( );
     void clear_link( );
 
+    void paint( );
+    void unpaint( );
+    bool is_painted( );
+
+    void mark( );
+    void unmark( );
+    bool is_marked( );
+
     void select( );
     void unselect( );
     bool is_selected( );
