@@ -152,7 +152,7 @@ mainwid::draw_sequence_on_pixmap( int a_seq )
 	int base_y = (c_mainwid_border +
 		      (c_seqarea_y + c_mainwid_spacing) * j);
 
-	int local_seq = a_seq % c_seqs_in_set;
+	/*int local_seq = a_seq % c_seqs_in_set;*/
 
 	m_gc->set_foreground(m_black);
 	m_pixmap->draw_rectangle(m_gc, true,
@@ -207,11 +207,11 @@ mainwid::draw_sequence_on_pixmap( int a_seq )
 	
 	    /* midi channel + key + timesig */
 
-	    char key =  m_seq_to_char[local_seq];
-	  
+		/*char key =  m_seq_to_char[local_seq];*/
+
 	    char str[20];
 	    sprintf( str, 
-		     "%d-%d %d/%d", 
+		     "%d-%d %ld/%ld",
 		     seq->get_midi_bus(), 
 		     seq->get_midi_channel()+1,
 		     seq->get_bpm(), seq->get_bw() );
@@ -498,16 +498,10 @@ mainwid::seq_from_xy( int a_x, int a_y )
 bool
 mainwid::on_button_press_event(GdkEventButton* a_p0)
 {
-
     grab_focus();
 
     m_current_seq = seq_from_xy( (int) a_p0->x, (int) a_p0->y );
 
-    // launch menu (right button)
-    if (  m_current_seq != -1 && a_p0->button == 3  ){
-        popup_menu();
-    }
-
     if ( m_current_seq != -1  && a_p0->button == 1 ){
  
 	m_button_down = true;
@@ -531,41 +525,46 @@ mainwid::on_button_release_event(GdkEventButton* a_p0)
     if ( m_current_seq != -1  && a_p0->button == 1 && !m_moving ){
 
         if ( m_mainperf->is_active( m_current_seq )){
-		
-			//sequence *seq = m_mainperf->get_sequence(  m_current_seq );
-			//seq->set_playing( !seq->get_playing() );
 
-		m_mainperf->sequence_playing_toggle( m_current_seq );
+            //sequence *seq = m_mainperf->get_sequence(  m_current_seq );
+            //seq->set_playing( !seq->get_playing() );
 
-	    draw_sequence_on_pixmap(  m_current_seq );
-	    draw_sequence_pixmap_on_window( m_current_seq);
-	}
+            m_mainperf->sequence_playing_toggle( m_current_seq );
+
+            draw_sequence_on_pixmap(  m_current_seq );
+            draw_sequence_pixmap_on_window( m_current_seq);
+        }
     }
 
     if ( a_p0->button == 1 && m_moving ){
 
-	m_moving = false;
+        m_moving = false;
 
-	if ( ! m_mainperf->is_active( m_current_seq ) && m_current_seq != -1
-		 && !m_mainperf->is_sequence_in_edit( m_current_seq )  ){
+        if ( ! m_mainperf->is_active( m_current_seq ) && m_current_seq != -1
+                && !m_mainperf->is_sequence_in_edit( m_current_seq )  ){
 
-	    m_mainperf->new_sequence( m_current_seq  );
-	    *(m_mainperf->get_sequence( m_current_seq )) = m_moving_seq;
-	
-	    draw_sequence_on_pixmap( m_current_seq  );
-	    draw_sequence_pixmap_on_window( m_current_seq );
+            m_mainperf->new_sequence( m_current_seq  );
+            *(m_mainperf->get_sequence( m_current_seq )) = m_moving_seq;
 
-	} else {
+            draw_sequence_on_pixmap( m_current_seq  );
+            draw_sequence_pixmap_on_window( m_current_seq );
 
-	    m_mainperf->new_sequence( m_old_seq  );
-	    *(m_mainperf->get_sequence( m_old_seq )) = m_moving_seq;
-	
-	    draw_sequence_on_pixmap( m_old_seq  );
-	    draw_sequence_pixmap_on_window( m_old_seq );
-	}
+        } else {
+
+            m_mainperf->new_sequence( m_old_seq  );
+            *(m_mainperf->get_sequence( m_old_seq )) = m_moving_seq;
+
+            draw_sequence_on_pixmap( m_old_seq  );
+            draw_sequence_pixmap_on_window( m_old_seq );
+        }
 
 
     }
+    // launch menu (right button)
+    if (  m_current_seq != -1 && a_p0->button == 3  ){
+        popup_menu();
+    }
+
 
     return true;
 }
