@@ -33,35 +33,12 @@
 #ifndef SEQ24_MAINWINDOW
 #define SEQ24_MAINWINDOW
 
-#include <gtkmm/button.h>
-#include <gtkmm/window.h>
-#include <gtkmm/accelgroup.h>
-#include <gtkmm/box.h>
-#include <gtkmm/main.h>
-#include <gtkmm/menu.h>
-#include <gtkmm/menubar.h>
-#include <gtkmm/eventbox.h>
-#include <gtkmm/window.h>
-#include <gtkmm/table.h>
-#include <gtkmm/drawingarea.h>
-#include <gtkmm/label.h>
-#include <gtkmm/viewport.h> 
-#include <gtkmm/fileselection.h>
-#include <gtkmm/dialog.h>
-#include <gtkmm/messagedialog.h>
-#include <gtkmm/textview.h>
-#include <gtkmm/arrow.h>
-#include <gtkmm/spinbutton.h>
-#include <gtkmm/progressbar.h>
-#include <gtkmm/dialog.h>
-#include <gtkmm/label.h>
-#include <gdkmm/cursor.h>
-#include <gtkmm/image.h>
-
+#include <map>
+#include <gtkmm.h>
+#include <string>
 
 #include "globals.h"
 
-#include <map>
 
 
 using namespace Gtk;
@@ -75,11 +52,11 @@ class mainwnd : public Gtk::Window
    
  private:
 
-    bool      m_quit;
+    bool      m_modified;
     
     MenuBar  *m_menubar;
     Menu     *m_menu_file;
-    Menu     *m_menu_control;
+    Menu     *m_menu_view;
     Menu     *m_menu_help;
 
     perform  *m_mainperf;
@@ -94,8 +71,6 @@ class mainwnd : public Gtk::Window
     
     Button      *m_button_stop;
     Button      *m_button_play;
-    Button      *m_button_test;
-
     Button      *m_button_perfedit;
 
     SpinButton  *m_spinbutton_bpm;
@@ -109,35 +84,35 @@ class mainwnd : public Gtk::Window
 
     Entry       *m_entry_notes;
 
-    SigC::Connection   m_timeout_connect;
+    sigc::connection   m_timeout_connect;
 
-    void file_new_dialog( void );
-    void file_save_dialog( void );
-    void file_saveas_dialog( void );
-    void file_open_dialog( void );
     void file_import_dialog( void );
-    void file_exit_dialog( void );
-
     void options_dialog( void );
     void about_dialog( void );
 
-
     void adj_callback_ss( );
     void adj_callback_bpm( );
-
     void edit_callback_notepad( );
-
     bool timer_callback( );
 
     void start_playing();
     void stop_playing();
-    void test();
-
     void open_performance_edit( );
-
     void sequence_key( int a_seq );
-
-    void set_window_title_filename( std::string a_file );
+    void update_window_title();
+    void toLower(basic_string<char>&);
+    bool is_modified();
+    void file_new();
+    void file_open();
+    void file_save();
+    void file_save_as();
+    void file_exit();
+    void new_file();
+    void open_file(const std::string&);
+    bool save_file();
+    void choose_file();
+    int query_save_changes();
+    bool is_save();
 
  public:
 
