@@ -20,7 +20,7 @@
 
 #include "optionsfile.h"
 #include <iostream>
-
+std::string last_used_dir;
 optionsfile::optionsfile( string a_name ) :
     configfile( a_name )
 {
@@ -53,11 +53,11 @@ optionsfile::parse( perform *a_perf )
 
     line_after( &file, "[midi-control]" );
 
-    int sequences = 0;
-    sscanf( m_line, "%d", &sequences );
+    unsigned int sequences = 0;
+    sscanf( m_line, "%u", &sequences );
     next_data_line( &file );
 
-    for ( int i=0; i<sequences; ++i ){
+    for ( unsigned int i=0; i<sequences; ++i ){
 
         int sequence = 0;
         
@@ -119,15 +119,15 @@ optionsfile::parse( perform *a_perf )
         next_data_line( &file );
     }
 
-    sscanf( m_line, "%ld %ld", &a_perf->m_key_bpm_up,
+    sscanf( m_line, "%u %u", &a_perf->m_key_bpm_up,
                              &a_perf->m_key_bpm_dn );
     next_data_line( &file );
 
-    sscanf( m_line, "%ld %ld", &a_perf->m_key_screenset_up,
+    sscanf( m_line, "%u %u", &a_perf->m_key_screenset_up,
                              &a_perf->m_key_screenset_dn );
     next_data_line( &file );
 
-    sscanf( m_line, "%ld %ld %ld %ld",
+    sscanf( m_line, "%u %u %u %u",
             &a_perf->m_key_replace,
             &a_perf->m_key_queue,
             &a_perf->m_key_snapshot_1,
@@ -177,6 +177,10 @@ optionsfile::parse( perform *a_perf )
     sscanf( m_line, "%ld", &flag );
     global_manual_alsa_ports = (bool) flag;
 
+    /* last used dir  */
+    line_after( &file, "[last-used-dir]" );
+    last_used_dir.assign(m_line);
+
     file.close();
 
     return true;
@@ -343,6 +347,10 @@ optionsfile::write( perform *a_perf  )
          << global_jack_start_mode << "\n\n";
 
     
+    file << "\n\n\n[last-used-dir]\n\n"
+         << "# Last used directory.\n" 
+         << last_used_dir << "\n\n";
+
     file.close();
     return true;
 
