@@ -22,36 +22,19 @@
 #define SEQ24_OPTIONSFILE
 
 #include "perform.h"
+#include "configfile.h"
 #include <fstream>
 #include <string>
 #include <list>
 
-class optionsfile 
+class optionsfile  : public configfile
 {
 
- private:
-    
-    int m_pos;
-    string m_name;
-
-    /* holds our data */
-    unsigned char *m_d;
-    
-    list<unsigned char> m_l;
-
-    char m_line[1024];
-
-    bool m_done;
-    
-    void next_data_line( ifstream *a_file);
-    void line_after( ifstream *a_file, string a_tag);
-
  public:
 
     optionsfile( string a_name );
- 
-    ~optionsfile(  );
-
+    ~optionsfile( );
+    
     bool parse( perform *a_perf );
     bool write( perform *a_perf );
 
