@@ -30,21 +30,23 @@
 #include "copy.xpm"
 #include "undo.xpm"
 #include "down.xpm"
+#include "perfedit.xpm"
 
-using namespace SigC;
+using namespace sigc;
 
 perfedit::perfedit( perform *a_perf ) 
 {
-
     using namespace Menu_Helpers;
 
+    set_icon(Gdk::Pixbuf::create_from_xpm_data(perfedit_xpm));
+
     /* set the performance */
     m_snap = c_ppqn / 4;
 
     m_mainperf = a_perf;
 
     /* main window */
-    set_title ( "Song Editor" );
+    set_title( "seq24 - Song Editor");
     set_size_request(700, 400);
 
     /* tooltips */
@@ -99,12 +101,12 @@ perfedit::perfedit( perform *a_perf )
     m_table->attach( *m_button_grow, 2, 3, 3, 4, Gtk::SHRINK, Gtk::SHRINK  );
 
     m_menu_snap =   manage( new Menu());
-    m_menu_snap->items().push_back(MenuElem("1/1",     SigC::bind(mem_fun(*this,&perfedit::set_snap), 1  )));
-    m_menu_snap->items().push_back(MenuElem("1/2",   SigC::bind(mem_fun(*this,&perfedit::set_snap), 2  )));
-    m_menu_snap->items().push_back(MenuElem("1/4",   SigC::bind(mem_fun(*this,&perfedit::set_snap), 4  )));
-    m_menu_snap->items().push_back(MenuElem("1/8",   SigC::bind(mem_fun(*this,&perfedit::set_snap), 8  )));
-    m_menu_snap->items().push_back(MenuElem("1/16",   SigC::bind(mem_fun(*this,&perfedit::set_snap), 16  )));
-    m_menu_snap->items().push_back(MenuElem("1/32",   SigC::bind(mem_fun(*this,&perfedit::set_snap), 32  )));
+    m_menu_snap->items().push_back(MenuElem("1/1",     sigc::bind(mem_fun(*this,&perfedit::set_snap), 1  )));
+    m_menu_snap->items().push_back(MenuElem("1/2",   sigc::bind(mem_fun(*this,&perfedit::set_snap), 2  )));
+    m_menu_snap->items().push_back(MenuElem("1/4",   sigc::bind(mem_fun(*this,&perfedit::set_snap), 4  )));
+    m_menu_snap->items().push_back(MenuElem("1/8",   sigc::bind(mem_fun(*this,&perfedit::set_snap), 8  )));
+    m_menu_snap->items().push_back(MenuElem("1/16",   sigc::bind(mem_fun(*this,&perfedit::set_snap), 16  )));
+    m_menu_snap->items().push_back(MenuElem("1/32",   sigc::bind(mem_fun(*this,&perfedit::set_snap), 32  )));
  
     
     /* snap */
@@ -121,11 +123,11 @@ perfedit::perfedit( perform *a_perf )
     m_menu_bw = manage( new Menu() );
 
     /* bw */
-    m_menu_bw->items().push_back(MenuElem("1", SigC::bind(mem_fun(*this,&perfedit::set_bw), 1  )));
-    m_menu_bw->items().push_back(MenuElem("2", SigC::bind(mem_fun(*this,&perfedit::set_bw), 2  )));
-    m_menu_bw->items().push_back(MenuElem("4", SigC::bind(mem_fun(*this,&perfedit::set_bw), 4  )));
-    m_menu_bw->items().push_back(MenuElem("8", SigC::bind(mem_fun(*this,&perfedit::set_bw), 8  )));
-    m_menu_bw->items().push_back(MenuElem("16", SigC::bind(mem_fun(*this,&perfedit::set_bw), 16 )));
+    m_menu_bw->items().push_back(MenuElem("1", sigc::bind(mem_fun(*this,&perfedit::set_bw), 1  )));
+    m_menu_bw->items().push_back(MenuElem("2", sigc::bind(mem_fun(*this,&perfedit::set_bw), 2  )));
+    m_menu_bw->items().push_back(MenuElem("4", sigc::bind(mem_fun(*this,&perfedit::set_bw), 4  )));
+    m_menu_bw->items().push_back(MenuElem("8", sigc::bind(mem_fun(*this,&perfedit::set_bw), 8  )));
+    m_menu_bw->items().push_back(MenuElem("16", sigc::bind(mem_fun(*this,&perfedit::set_bw), 16 )));
     
     char b[20];
     
@@ -135,7 +137,7 @@ perfedit::perfedit( perform *a_perf )
         
         /* length */
         m_menu_bpm->items().push_back(MenuElem(b, 
-                                               SigC::bind(mem_fun(*this,&perfedit::set_bpm),   
+                                               sigc::bind(mem_fun(*this,&perfedit::set_bpm),   
                                                     i+1 )));
     }
 
@@ -199,10 +201,7 @@ perfedit::perfedit( perform *a_perf )
     m_button_play = manage( new Button() );
     m_button_play->add(*manage( new Image(Gdk::Pixbuf::create_from_xpm_data( play2_xpm ))));
     m_button_play->signal_clicked().connect(  mem_fun( *this, &perfedit::start_playing));
-    m_tooltips->set_tip( *m_button_play, "Being playing at L marker." );
-
-
-
+    m_tooltips->set_tip( *m_button_play, "Begin playing at L marker." );
 
 
     m_hlbox->pack_end( *m_button_copy , false, false ); 
@@ -376,8 +375,6 @@ void perfedit::set_bw( int a_beat_width )
 }
 
 
-
-
 void 
 perfedit::on_realize()
 {
@@ -385,9 +382,6 @@ perfedit::on_realize()
     Gtk::Window::on_realize();
 
     Glib::signal_timeout().connect(mem_fun(*this,&perfedit::timeout ), c_redraw_ms);
-  
-  
- 
 }
 
 
@@ -422,9 +416,6 @@ perfedit::~perfedit()
 }
 
 
-
-
-
 bool 
 perfedit::on_delete_event(GdkEventAny *a_event)
 {
