@@ -26,7 +26,8 @@ perfnames::perfnames( perform *a_perf, Adjustment *a_vadjust ): DrawingArea(), s
     m_mainperf = a_perf;
 
     add_events( Gdk::BUTTON_PRESS_MASK | 
-		Gdk::BUTTON_RELEASE_MASK );
+		Gdk::BUTTON_RELEASE_MASK |
+		Gdk::SCROLL_MASK );
 
     /* set default size */	
     set_size_request( c_names_x, 100 );
@@ -294,6 +295,23 @@ perfnames::on_button_release_event(GdkEventButton* p0)
     return false;
 }
 
+bool
+perfnames::on_scroll_event( GdkEventScroll* a_ev )
+{
+	double val = m_vadjust->get_value();
+
+    if (  a_ev->direction == GDK_SCROLL_UP ){
+		val -= m_vadjust->get_step_increment();
+    }
+    if (  a_ev->direction == GDK_SCROLL_DOWN ){
+		val += m_vadjust->get_step_increment();
+    }
+
+	m_vadjust->clamp_page( val, val + m_vadjust->get_page_size());
+    return true;
+}
+
+
 void
 perfnames::on_size_allocate(Gtk::Allocation &a_r )
 {
