@@ -64,11 +64,13 @@ class perftime: public Gtk::DrawingArea
 
     int m_4bar_offset;
 
+    int m_snap, m_measure_length;
+
     void on_realize();
     bool on_expose_event(GdkEventExpose* a_ev);
     bool on_button_press_event(GdkEventButton* a_ev); 
     bool on_button_release_event(GdkEventButton* a_ev);
-    void on_size_allocate(GtkAllocation* a_r );
+    void on_size_allocate(Gtk::Allocation &a_r );
 
     void update_sizes();
     void draw_pixmap_on_window();
@@ -85,6 +87,7 @@ class perftime: public Gtk::DrawingArea
 
     void reset();
     void set_scale( int a_scale );
+    void set_guides( int a_snap, int a_measure );
 
     void increment_size();
 };
