@@ -30,9 +30,10 @@ seqkeys::seqkeys(sequence *a_seq,
     
     add_events( Gdk::BUTTON_PRESS_MASK | 
 		Gdk::BUTTON_RELEASE_MASK |
-                Gdk::ENTER_NOTIFY_MASK |
+		Gdk::ENTER_NOTIFY_MASK |
 		Gdk::LEAVE_NOTIFY_MASK |
-		Gdk::POINTER_MOTION_MASK );
+		Gdk::POINTER_MOTION_MASK |
+		Gdk::SCROLL_MASK);
 
     /* set default size */
     set_size_request( c_keyarea_x +1, 10 );
@@ -419,3 +420,23 @@ seqkeys::on_size_allocate(Gtk::Allocation& a_r )
     queue_draw();
  
 }
+
+
+bool
+seqkeys::on_scroll_event( GdkEventScroll* a_ev )
+{
+	double val = m_vadjust->get_value();
+
+	if ( a_ev->direction == GDK_SCROLL_UP ){
+		val -= m_vadjust->get_step_increment()/6;
+	} else if (  a_ev->direction == GDK_SCROLL_DOWN ){
+		val += m_vadjust->get_step_increment()/6;
+	} else {
+		return true;
+	}
+
+	m_vadjust->clamp_page( val, val + m_vadjust->get_page_size() );
+    return true;
+
+}
+
