@@ -136,8 +136,6 @@ seqroll::set_adding( bool a_adding )
 }
 
 
-
-
 void 
 seqroll::on_realize()
 {
@@ -176,8 +174,16 @@ seqroll::update_sizes()
     m_hadjust->set_lower( 0 );
     m_hadjust->set_upper( m_seq->get_length() );
     m_hadjust->set_page_size( m_window_x * m_zoom );
-    m_hadjust->set_step_increment( c_ppqn / 4 );
-    m_hadjust->set_page_increment( c_ppqn / 4 );
+    
+    /* The step increment is 1 semiquaver (1/16) note per zoom level */
+    m_hadjust->set_step_increment( (c_ppqn / 4) * m_zoom);
+    
+    /* The page increment is always one bar */
+    int page_increment = c_ppqn *
+                        m_seq->get_bpm() *
+                        (4.0 / m_seq->get_bw());
+    m_hadjust->set_page_increment(page_increment);
+    
 
     int h_max_value = ( m_seq->get_length() - (m_window_x * m_zoom));
     
@@ -255,7 +261,6 @@ seqroll::redraw()
 }
 
 
-
 /* updates background */
 void 
 seqroll::draw_background()
@@ -433,7 +438,6 @@ seqroll::set_key( int a_key )
 }
 
 
-
 /* draws background pixmap on main pixmap,
    then puts the events on */
 void 
@@ -470,133 +474,149 @@ seqroll::draw_progress_on_window()
 }
 
 
+void seqroll::draw_events_on( Glib::RefPtr<Gdk::Drawable> a_draw ) {
 
-void seqroll::draw_events_on( Glib::RefPtr<Gdk::Drawable> a_draw )
-{
-   
-    
-    long tick_s;
-    long tick_f;
-    int note;
-    
-    int note_x;
-    int note_width;
-    int note_y;
-    int note_height;
+	long tick_s;
+	long tick_f;
+	int note;
 
-    bool selected;
+	int note_x;
+	int note_width;
+	int note_y;
+	int note_height;
 
-    int velocity;
+	bool selected;
 
-    draw_type dt;
+	int velocity;
 
-    
+	draw_type dt;
 
-    int start_tick = m_scroll_offset_ticks ;
-    int end_tick = (m_window_x * m_zoom) + m_scroll_offset_ticks;
-    
-    sequence *seq = NULL;
-    for( int method=0; method<2; ++method ){
-        
-        if ( method == 0 && m_drawing_background_seq  ){
-            
-            if ( m_perform->is_active( m_background_sequence )){
-                seq =m_perform->get_sequence( m_background_sequence );
-            }
-            else{
-                method++;
-            }
-        }
-        else if ( method == 0 ){
-            method++;
-        }
-        
-        
-        if ( method==1){
-            seq = m_seq;
-        }
 
-        /* draw boxes from sequence */
-        m_gc->set_foreground( m_black );
-        seq->reset_draw_marker();
 
-        while ( (dt = seq->get_next_note_event( &tick_s, &tick_f, &note, 
-                                                &selected, &velocity )) != DRAW_FIN ){
-            
-            if ( (tick_s >= start_tick && tick_s <= end_tick) ||
-                 ((dt == DRAW_NORMAL_LINKED) &&
-                  (tick_f >= start_tick && tick_f <= end_tick))){
-                
-                /* turn into screen corrids */
-                note_x = tick_s / m_zoom;
-                note_y = c_rollarea_y -(note * c_key_y) - c_key_y - 1 + 2;
-                note_height = c_key_y - 3;
-                
-                //printf( "drawing note[%d] tick_start[%d] tick_end[%d]\n",
-                //	    note, tick_start, tick_end );
-                
-                int in_shift = 0;
-                int length_add = 0;
-                
-                if ( dt == DRAW_NORMAL_LINKED ){
-                    
-                    note_width = (tick_f - tick_s) / m_zoom;
-                    if ( note_width < 1 ) note_width = 1;
-                    
-                }
-                else {
-                    note_width = 8 / m_zoom;
-                }
-                
-                if ( dt == DRAW_NOTE_ON ){
-                    
-                    in_shift = 0;
-                    length_add = 2;
-                }       
-                
-                if ( dt == DRAW_NOTE_OFF ){
-                    
-                    in_shift = -1;
-                    length_add = 1;
-                }
-                
-                note_x -= m_scroll_offset_x;
-                note_y -= m_scroll_offset_y;
-                
-                m_gc->set_foreground(m_black);
-                /* draw boxes from sequence */
+	int start_tick = m_scroll_offset_ticks ;
+	int end_tick = (m_window_x * m_zoom) + m_scroll_offset_ticks;
 
-                if ( method == 0 )
-                    m_gc->set_foreground( m_dk_grey );
-                
-                a_draw->draw_rectangle(m_gc,true,
-                                       note_x,
-                                       note_y, 
-                                       note_width, 
-                                       note_height);
-                
-                /* draw inside box if there is room */
-                if ( note_width > 3 ){
-                    
-                    if ( selected )
-                        m_gc->set_foreground(m_red);
-                    else
-                        m_gc->set_foreground(m_white);
+	sequence *seq = NULL;
+	for( int method=0; method<2; ++method )	{
 
-                    if ( method == 1 )
-                        a_draw->draw_rectangle(m_gc,true,
-                                               note_x + 1 + in_shift,
-                                               note_y + 1, 
-                                               note_width - 3 + length_add, 
-                                               note_height - 3);	   
-                }
-            }
-        }
-    }
+		if ( method == 0 && m_drawing_background_seq  ){
+
+			if ( m_perform->is_active( m_background_sequence )){
+				seq =m_perform->get_sequence( m_background_sequence );
+			} else {
+				method++;
+			}
+		} else if ( method == 0 ){
+			method++;
+		}
+
+
+		if ( method==1){
+			seq = m_seq;
+		}
+
+		/* draw boxes from sequence */
+		m_gc->set_foreground( m_black );
+		seq->reset_draw_marker();
+
+		while ( (dt = seq->get_next_note_event( &tick_s, &tick_f, &note, &selected, &velocity )) != DRAW_FIN ) {
+
+			if ((tick_s >= start_tick && tick_s <= end_tick) ||
+				( (dt == DRAW_NORMAL_LINKED) && (tick_f >= start_tick && tick_f <= end_tick))
+			) {
+
+				/* turn into screen corrids */
+				note_x = tick_s / m_zoom;
+				note_y = c_rollarea_y -(note * c_key_y) - c_key_y - 1 + 2;
+				note_height = c_key_y - 3;
+
+//				printf( "DEBUG: drawing note[%d] tick_s[%d] tick_f[%d] start_tick[%d] end_tick[%d]\n",
+//				note, tick_s, tick_f, start_tick, end_tick );
+//				printf( "DEBUG: seq.get_lenght() = %d\n",  m_seq->get_length());
+
+				int in_shift = 0;
+				int length_add = 0;
+
+				if ( dt == DRAW_NORMAL_LINKED ){
+
+					if (tick_f >= tick_s) {
+						note_width = (tick_f - tick_s) / m_zoom;
+						if ( note_width < 1 ) note_width = 1;
+					} else {
+						note_width = (m_seq->get_length() - tick_s) / m_zoom;
+					}
+
+				} else {
+					note_width = 16 / m_zoom;
+				}
+
+				if ( dt == DRAW_NOTE_ON ){
+					in_shift = 0;
+					length_add = 2;
+				}       
+
+				if ( dt == DRAW_NOTE_OFF ){
+					in_shift = -1;
+					length_add = 1;
+				}
+
+				note_x -= m_scroll_offset_x;
+				note_y -= m_scroll_offset_y;
+
+				m_gc->set_foreground(m_black);
+				/* draw boxes from sequence */
+
+				if ( method == 0 )
+					m_gc->set_foreground( m_dk_grey );
+
+				a_draw->draw_rectangle(	m_gc,true,
+							note_x,
+							note_y, 
+							note_width, 
+							note_height);
+				if (tick_f < tick_s) {
+					a_draw->draw_rectangle(	m_gc,true,
+								0,
+								note_y, 
+								tick_f/m_zoom, 
+								note_height);
+				}
+
+				/* draw inside box if there is room */
+				if ( note_width > 3 ){
+
+					if ( selected )
+						m_gc->set_foreground(m_red);
+					else
+						m_gc->set_foreground(m_white);
+
+					if ( method == 1 ) {
+						if (tick_f >= tick_s) {
+							a_draw->draw_rectangle(	m_gc,true,
+										note_x + 1 + in_shift,
+										note_y + 1, 
+										note_width - 3 + length_add, 
+										note_height - 3);
+						} else {
+							a_draw->draw_rectangle(	m_gc,true,
+										note_x + 1 + in_shift,
+										note_y + 1, 
+										note_width , 
+										note_height - 3);
+							a_draw->draw_rectangle(	m_gc,true,
+										0,
+										note_y + 1, 
+										(tick_f/m_zoom) - 3 + length_add, 
+										note_height - 3);
+						}
+                                        }
+				}
+			}
+		}
+	}
 } 
 
 
-
 /* fills main pixmap with events */
 void 
 seqroll::draw_events_on_pixmap()
@@ -615,7 +635,6 @@ seqroll::idle_redraw()
 }
 
 
-
 void 
 seqroll::draw_selection_on_window()
 {
@@ -752,7 +771,6 @@ seqroll::force_draw(void )
 }
 
 
-
 /* takes screen corrdinates, give us notes and ticks */
 void 
 seqroll::convert_xy( int a_x, int a_y, long *a_tick, int *a_note)
@@ -771,7 +789,6 @@ seqroll::convert_tn( long a_ticks, int a_note, int *a_x, int *a_y)
 }
 
 
-
 /* checks mins / maxes..  the fills in x,y
    and width and height */
 void 
@@ -797,6 +814,7 @@ seqroll::xy_to_rect( int a_x1,  int a_y1,
     }
 }
 
+
 void
 seqroll::convert_tn_box_to_rect( long a_tick_s, long a_tick_f,
 				 int a_note_h, int a_note_l,
@@ -815,7 +833,6 @@ seqroll::convert_tn_box_to_rect( long a_tick_s, long a_tick_f,
 }
 
 
-
 void
 seqroll::start_paste( )
 {
@@ -1029,7 +1046,7 @@ seqroll::on_button_press_event(GdkEventButton* a_ev)
 }
 
 
-    bool
+bool
 seqroll::on_button_release_event(GdkEventButton* a_ev)
 {
     long tick_s;
@@ -1136,7 +1153,6 @@ seqroll::on_button_release_event(GdkEventButton* a_ev)
     }
     return true;
 }
-
  
 
 bool
@@ -1205,8 +1221,6 @@ seqroll::snap_x( int *a_x )
 }
 
 
-
-
 bool
 seqroll::on_enter_notify_event(GdkEventCrossing* a_p0)
 {
@@ -1215,7 +1229,6 @@ seqroll::on_enter_notify_event(GdkEventCrossing* a_p0)
 }
 
 
-
 bool
 seqroll::on_leave_notify_event(GdkEventCrossing* a_p0)
 {
@@ -1224,7 +1237,6 @@ seqroll::on_leave_notify_event(GdkEventCrossing* a_p0)
 }
 
 
-
 bool
 seqroll::on_focus_in_event(GdkEventFocus*)
 {
@@ -1249,9 +1261,22 @@ seqroll::on_key_press_event(GdkEventKey* a_p0)
 {
     bool ret = false;
 
+	if ( a_p0->keyval ==  GDK_space ){
+		    if (is_pattern_playing) {
+			    m_perform->stop_jack();
+			    m_perform->stop();
+		    	    is_pattern_playing=false;
+		    } else {
+			    m_perform->position_jack( false );  
+			    m_perform->start( false );
+			    m_perform->start_jack( );
+		    	    is_pattern_playing=true;
+ 		    }
+            }
+
     if ( a_p0->type == GDK_KEY_PRESS ){
 
-        if ( a_p0->keyval ==  GDK_Delete ){
+        if ( a_p0->keyval ==  GDK_Delete || a_p0->keyval == GDK_BackSpace ){
 
             m_seq->push_undo();
             m_seq->mark_selected();
@@ -1304,8 +1329,6 @@ seqroll::on_key_press_event(GdkEventKey* a_p0)
 }
 
 
-
-
 void 
 seqroll::set_data_type( unsigned char a_status, unsigned char a_control = 0 )
 {
@@ -1314,7 +1337,6 @@ seqroll::set_data_type( unsigned char a_status, unsigned char a_control = 0 )
 }
 
 
-
 void
 seqroll::on_size_allocate(Gtk::Allocation& a_r )
 {
@@ -1327,9 +1349,20 @@ seqroll::on_size_allocate(Gtk::Allocation& a_r )
  
 }
 
+
 bool
 seqroll::on_scroll_event( GdkEventScroll* a_ev )
 {
+    //printf("seqroll::on_scroll_event(state=%d)\n", a_ev->state);
+
+    guint modifiers;    // Used to filter out caps/num lock etc.
+    modifiers = gtk_accelerator_get_default_mod_mask ();
+    
+    /* This scroll event only handles basic scrolling without any
+     * modifier keys such as GDK_CONTROL_MASK or GDK_SHIFT_MASK */
+    if ((a_ev->state & modifiers) != 0)
+        return false;
+
 	double val = m_vadjust->get_value();
 
 	if ( a_ev->direction == GDK_SCROLL_UP ){
