@@ -75,7 +75,7 @@ class seqtime: public Gtk::DrawingArea
 
     bool idle_progress();
 
-    void on_size_allocate(GtkAllocation* );
+    void on_size_allocate(Gtk::Allocation& );
 
     void change_horz( void );
 
