@@ -83,7 +83,9 @@ class sequence
     trigger m_trigger_clipboard;
 
     stack < list < event > >m_list_undo;
+    stack < list < event > >m_list_redo;
     stack < list < trigger > >m_list_trigger_undo;
+    stack < list < trigger > >m_list_trigger_redo;
 
     /* markers */
     list < event >::iterator m_iterator_play;
@@ -111,6 +113,7 @@ class sequence
     bool m_was_playing;
     bool m_playing;
     bool m_recording;
+    bool m_quanized_rec;
     bool m_thru;
     bool m_queued;
 
@@ -139,12 +142,14 @@ class sequence
     /* length of sequence in pulses 
        should be powers of two in bars */
     long m_length;
+    long m_snap_tick;
 
     /* these are just for the editor to mark things
        in correct time */
     //long m_length_measures;
     long m_time_beats_per_measure;
     long m_time_beat_width;
+    long m_rec_vol;
 
     /* locking */
     mutex m_mutex;
@@ -179,6 +184,7 @@ class sequence
 
     void push_undo (void);
     void pop_undo (void);
+    void pop_redo (void);
 
     void push_trigger_undo (void);
     void pop_trigger_undo (void);
@@ -199,6 +205,7 @@ class sequence
 
     void set_bw (long a_beat_width);
     long get_bw (void);
+    void set_rec_vol (long a_rec_vol);
 
     void set_song_mute (bool a_mute);
     bool get_song_mute (void);
@@ -246,6 +253,9 @@ class sequence
 
     void set_recording (bool);
     bool get_recording ();
+    void set_snap_tick( int a_st );
+    void set_quanized_rec( bool a_qr );
+    bool get_quanidez_rec( );
 
     void set_thru (bool);
     bool get_thru ();
